@@ -134,7 +134,7 @@ class ImagebuilderClient:
     def create_distribution_configuration(
         self,
         name: str,
-        distributions: List[DistributionTypeDef],
+        distributions: List["DistributionTypeDef"],
         clientToken: str,
         description: str = None,
         tags: Dict[str, str] = None,
@@ -149,7 +149,7 @@ class ImagebuilderClient:
         infrastructureConfigurationArn: str,
         clientToken: str,
         distributionConfigurationArn: str = None,
-        imageTestsConfiguration: ImageTestsConfigurationTypeDef = None,
+        imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = None,
         enhancedImageMetadataEnabled: bool = None,
         tags: Dict[str, str] = None,
     ) -> CreateImageResponseTypeDef:
@@ -165,9 +165,9 @@ class ImagebuilderClient:
         clientToken: str,
         description: str = None,
         distributionConfigurationArn: str = None,
-        imageTestsConfiguration: ImageTestsConfigurationTypeDef = None,
+        imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = None,
         enhancedImageMetadataEnabled: bool = None,
-        schedule: ScheduleTypeDef = None,
+        schedule: "ScheduleTypeDef" = None,
         status: Literal["DISABLED", "ENABLED"] = None,
         tags: Dict[str, str] = None,
     ) -> CreateImagePipelineResponseTypeDef:
@@ -179,11 +179,11 @@ class ImagebuilderClient:
         self,
         name: str,
         semanticVersion: str,
-        components: List[ComponentConfigurationTypeDef],
+        components: List["ComponentConfigurationTypeDef"],
         parentImage: str,
         clientToken: str,
         description: str = None,
-        blockDeviceMappings: List[InstanceBlockDeviceMappingTypeDef] = None,
+        blockDeviceMappings: List["InstanceBlockDeviceMappingTypeDef"] = None,
         tags: Dict[str, str] = None,
     ) -> CreateImageRecipeResponseTypeDef:
         """
@@ -199,7 +199,7 @@ class ImagebuilderClient:
         instanceTypes: List[str] = None,
         securityGroupIds: List[str] = None,
         subnetId: str = None,
-        logging: LoggingTypeDef = None,
+        logging: "LoggingTypeDef" = None,
         keyPair: str = None,
         terminateInstanceOnFailure: bool = None,
         snsTopicArn: str = None,
@@ -449,7 +449,7 @@ class ImagebuilderClient:
     def update_distribution_configuration(
         self,
         distributionConfigurationArn: str,
-        distributions: List[DistributionTypeDef],
+        distributions: List["DistributionTypeDef"],
         clientToken: str,
         description: str = None,
     ) -> UpdateDistributionConfigurationResponseTypeDef:
@@ -465,9 +465,9 @@ class ImagebuilderClient:
         clientToken: str,
         description: str = None,
         distributionConfigurationArn: str = None,
-        imageTestsConfiguration: ImageTestsConfigurationTypeDef = None,
+        imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = None,
         enhancedImageMetadataEnabled: bool = None,
-        schedule: ScheduleTypeDef = None,
+        schedule: "ScheduleTypeDef" = None,
         status: Literal["DISABLED", "ENABLED"] = None,
     ) -> UpdateImagePipelineResponseTypeDef:
         """
@@ -483,7 +483,7 @@ class ImagebuilderClient:
         instanceTypes: List[str] = None,
         securityGroupIds: List[str] = None,
         subnetId: str = None,
-        logging: LoggingTypeDef = None,
+        logging: "LoggingTypeDef" = None,
         keyPair: str = None,
         terminateInstanceOnFailure: bool = None,
         snsTopicArn: str = None,
